Package 'flexoki'

Title: Inky Color Schemes
Description: Provides color palettes designed to be reminiscent of text on paper. The color schemes were taken from <https://stephango.com/flexoki>. Includes discrete, continuous, and binned scales that are not necessarily color-blind friendly. Simple scale and theme functions are available for use with 'ggplot2'.
Authors: Christopher T. Kenny [aut, cre] (ORCID: <https://orcid.org/0000-0002-9386-6860>)
Maintainer: Christopher T. Kenny <[email protected]>
License: MIT + file LICENSE
Version: 0.0.2
Built: 2026-05-31 06:20:58 UTC
Source: https://github.com/christopherkenny/flexoki

Help Index


'Flexoki' Color Palettes

Description

Color palettes from Steph Ango's https://stephango.com/flexoki.

Usage

flexoki

Format

list of palette::palette vectors

Examples

plot(flexoki$dark)
plot(flexoki$light)

Binned 'Flexoki' Color Scales for ggplot2

Description

Binned 'Flexoki' Color Scales for ggplot2

Usage

scale_color_flexoki_b(palette = "red", ..., reverse = FALSE)

scale_fill_flexoki_b(palette = "red", ..., reverse = FALSE)

scale_colour_flexoki_b(palette = "red", ..., reverse = FALSE)

Arguments

palette

palette from names(flexoki) to use

...

arguments passed on to ggplot2::discrete_scale()

reverse

Should the vector be reversed? Default is FALSE.

Value

A ggplot2::Scale

Examples

ggplot2::faithfuld |>
  ggplot2::ggplot() +
  ggplot2::geom_tile(ggplot2::aes(waiting, eruptions, fill = density)) +
  scale_fill_flexoki_b(palette = 'red')

Continuous 'Flexoki' Color Scales for ggplot2

Description

Continuous 'Flexoki' Color Scales for ggplot2

Usage

scale_color_flexoki_c(palette = "red", ..., reverse = FALSE)

scale_fill_flexoki_c(palette = "red", ..., reverse = FALSE)

scale_colour_flexoki_c(palette = "red", ..., reverse = FALSE)

Arguments

palette

palette from names(flexoki) to use

...

arguments passed on to ggplot2::discrete_scale()

reverse

Should the vector be reversed? Default is FALSE.

Value

A ggplot2::Scale

Examples

ggplot2::faithfuld |>
  ggplot2::ggplot() +
  ggplot2::geom_tile(ggplot2::aes(waiting, eruptions, fill = density)) +
  scale_fill_flexoki_c(palette = 'red')

Discrete 'Flexoki' Color Scales for ggplot2

Description

Discrete 'Flexoki' Color Scales for ggplot2

Usage

scale_color_flexoki_d(palette = "dark", which = NULL, ..., reverse = FALSE)

scale_fill_flexoki_d(palette = "dark", which = NULL, ..., reverse = FALSE)

scale_colour_flexoki_d(palette = "dark", which = NULL, ..., reverse = FALSE)

Arguments

palette

palette from names(flexoki) to use

which

numeric indices of colors to use. NULL by default.

...

arguments passed on to ggplot2::discrete_scale()

reverse

Should the vector be reversed? Default is FALSE.

Value

A ggplot2::Scale

Examples

ggplot2::mpg |>
  ggplot2::ggplot() +
  ggplot2::geom_point(ggplot2::aes(displ, hwy, colour = class)) +
  scale_color_flexoki_d(palette = 'dark')

ggplot2::mpg |>
  ggplot2::ggplot() +
  ggplot2::geom_point(ggplot2::aes(displ, hwy, fill = class),
    pch = 23, color = 'transparent'
  ) +
  scale_fill_flexoki_d(palette = 'light')

Dark Theme

Description

Dark Theme

Usage

theme_flexoki_dark(base_size = 12, base_family = "mono", ...)

Arguments

base_size

base font size, given in pts.

base_family

base font family

...

additional parameters

Value

ggplot2 theme

Examples

ggplot2::mpg |>
  ggplot2::ggplot() +
  ggplot2::geom_point(ggplot2::aes(displ, hwy, colour = class)) +
  scale_color_flexoki_d(palette = 'dark') +
  theme_flexoki_dark()

Light Theme

Description

Light Theme

Usage

theme_flexoki_light(base_size = 12, base_family = "mono", ...)

Arguments

base_size

base font size, given in pts.

base_family

base font family

...

additional parameters

Value

ggplot2 theme

Examples

ggplot2::mpg |>
  ggplot2::ggplot() +
  ggplot2::geom_point(ggplot2::aes(displ, hwy, colour = class)) +
  scale_color_flexoki_d(palette = 'light') +
  theme_flexoki_light()